@@ -1,5 +1,5 @@
 /**
- * Isotope v1.5.06
+ * Isotope v1.5.07
  * An exquisite jQuery plugin for magical layouts
  * http://isotope.metafizzy.co
  *
@@ -1268,7 +1268,7 @@
   
   // ======================= imagesLoaded Plugin ===============================
   /*!
-   * jQuery imagesLoaded plugin v1.0.3
+   * jQuery imagesLoaded plugin v1.1.0
    * http://github.com/desandro/imagesloaded
    *
    * MIT License. by Paul Irish et al.
@@ -1289,32 +1289,35 @@
     var $this = this,
         $images = $this.find('img').add( $this.filter('img') ),
         len = $images.length,
-        blank = 'data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///ywAAAAAAQABAAACAUwAOw==';
+        blank = 'data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///ywAAAAAAQABAAACAUwAOw==',
+        loaded = [];
 
     function triggerCallback() {
       callback.call( $this, $images );
     }
 
     function imgLoaded( event ) {
-      if ( --len <= 0 && event.target.src !== blank ){
-        setTimeout( triggerCallback );
-        $images.unbind( 'load error', imgLoaded );
+      if ( event.target.src !== blank && $.inArray( this, loaded ) === -1 ){
+        loaded.push(this);
+        if ( --len <= 0 ){
+          setTimeout( triggerCallback );
+          $images.unbind( '.imagesLoaded', imgLoaded );
+        }
       }
     }
 
+    // if no images, trigger immediately
     if ( !len ) {
       triggerCallback();
     }
 
-    $images.bind( 'load error',  imgLoaded ).each( function() {
+    $images.bind( 'load.imagesLoaded error.imagesLoaded',  imgLoaded ).each( function() {
       // cached images don't fire load sometimes, so we reset src.
-      if (this.complete || this.complete === undefined){
-        var src = this.src;
-        // webkit hack from http://groups.google.com/group/jquery-dev/browse_thread/thread/eee6ab7b2da50e1f
-        // data uri bypasses webkit log warning (thx doug jones)
-        this.src = blank;
-        this.src = src;
-      }
+      var src = this.src;
+      // webkit hack from http://groups.google.com/group/jquery-dev/browse_thread/thread/eee6ab7b2da50e1f
+      // data uri bypasses webkit log warning (thx doug jones)
+      this.src = blank;
+      this.src = src;
     });
 
     return $this;
